==> tine20-allinone_2020.03.4.tar.bz2: Filemanager/js/Filemanager-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-04-06 12:24+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"

, "Password for download required"
: "Zum Herunterladen Passwort eingeben"

, "Submit"
: "Abschicken"

, "File not found!"
: "Datei nicht gefunden!"

, "Name"
: "Name"

, "Size"
: "Größe"

, "Last Modified"
: "Letzter Änderungszeitpunkt"

, "Description"
: "Beschreibung"

, "Folder, Folders"
: [
  "Ordner"
 ,"Ordner"

]
, "File, Files"
: [
  "Datei"
 ,"Dateien"

]
, "Default behavior when double-clicking on a Row"
: "Standardverhalten beim Doppelklicken auf eine Zeile"

, "Defines which action should be executed by default when double-clicked."
: "Legt fest, welche Aktion bei einem Doppelklick standardmäßig ausgeführt werden soll."

, "Invalid Filename"
: "Ungültiger Dateiname"

, "Content type"
: "Inhaltstyp"

, "path"
: "Pfad"

, "URL"
: "URL"

, "Password"
: "Passwort"

, "Valid until"
: "Gültig bis"

, "Send as e-mail"
: "Sende als E-Mail"

, "Download"
: "Herunterladen"

, "Create Public Link"
: "Öffentlichen Link erstellen"

, "Remove record"
: "Eintrag entfernen"

, "Creating new Download Link..."
: "Erstelle neuen Download Link..."

, "Deleting Download Links..."
: "Lösche Download Links..."

, "Deleting Download Link..."
: "Lösche Download Link..."

, "Created By"
: "Erstellt von"

, "Creation Time"
: "Erstellt am"

, "Expiration Time"
: "Fristablauf"

, "Access Count"
: "Anzahl der Zugriffe"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Revision"
: "Version"

, "This folder has own revision settings"
: "Dieser Ordner hat eigene Revisions Einstellungen"

, "Revision active"
: "Revision aktiv"

, "Limit revision amount to"
: "Revisionen limitieren auf"

, "Hold-back in months"
: "Vorhalten in Monaten"

, "Upload Failed"
: "Hochladen fehlgeschlagen"

, "It is not permitted to store files in this folder!"
: "In diesem Ordner dürfen keine Dateien abgelegt werden!"

, "Select a file"
: "Wähle eine Datei"

, "Select files"
: "Wähle Dateien aus"

, "Select a folder"
: "Wähle einen Ordner aus"

, "Select folders"
: "Ordner Auswählen"

, "Select an item"
: "Wähle einen Artikel aus"

, "Select items"
: "Artikel Auswählen"

, "Checking ..."
: "Prüfe…"

, "Overwrite Existing File?"
: "Bestehende Datei Überschreiben?"

, "Do you really want to overwrite the selected file?"
: "Wollen Sie wirklich die ausgewählten Dateien überschreiben?"

, "Tags"
: "Tags"

, "Revision Size"
: "Revisions Größe"

, "Total size of all available revisions"
: "Gesamtgröße der verfügbaren Revisionen"

, "Indexed"
: "Indiziert"

, "File contents is part of the search index"
: "Dateiinhalte sind im Suchindex"

, "Upload"
: "Hochladen"

, "Open Data Safe"
: "Datentresor öffnen"

, "Folder Up"
: "Aufwärts"

, "Close Data Safe"
: "Datentresor schließen"

, "Filemanager"
: "Dateimanager"

, "Save locally"
: "Lokal speichern"

, "Close"
: "Schließen"

, "Loading preview ..."
: "Lade Vorschau …"

, "Edit folder"
: "Ordner bearbeiten"

, "edit file"
: "Datei bearbeiten"

, "Public Links"
: "Öffentliche Links"

, "Type"
: "Typ"

, "Not yet indexed"
: "Noch nicht indiziert"

, "Modified By"
: "Zuletzt geändert von"

, "Enter description"
: "Beschreibung eingeben"

, "Service Unavailable"
: "Dienst nicht verfügbar"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Der Dateimanager ist nicht korrekt konfiguriert. Bitte kontaktieren sie ihren Administrator oder ziehen sie die {0}Tine 2.0 Dokumentation{1} zu Rate."

, "File(s) already exists"
: "Datei(en) schon vorhanden"

, "Do you want to replace the following file(s)?"
: "Möchten Sie die folgenden Datei(en) ersetzen?"

, "An error occurred creating this folder"
: "Beim Erstellen dieses Ordners ist ein Fehler aufgetreten"

, "Item with this name already exists!"
: "Item(s) mit diesem Namen schon vorhanden!"

, "Whole Filemanager"
: "Gesamter Dateimanager"

, "This Folder"
: "Dieser Ordner"

, "Search"
: "Suche"

, "The grant to download files"
: "Das Recht, Dateien zu herunterzuladen"

, "Publish"
: "Veröffentlichen"

, "The grant to create anonymous download links for files"
: "Das Recht, anonyme Download Links für Dateien zu erstellen"

, "Copying data .. {0}"
: "Kopiere Daten .. {0}"

, "Moving data .. {0}"
: "Verschiebe Daten .. {0}"

, "Please wait"
: "Bitte warten"

, "Error while uploading \"{fileName}\". Please try again later."
: "Fehler beim Hochladen von „{fileName}“ . Bitte versuchen Sie es später noch einmal."

, "Quick Search"
: "Schnellsuche"

, "Content Type"
: "Inhaltstyp"

, "File Contents"
: "Dateiinhalt"

, "Download Link, Download Links"
: [
  "Download Link"
 ,"Download Links"

]
, "Node Download Links"
: "Knoten Download Links"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: "Schade, gerne hätte Tine 2.0 Ihnen jetzt den Inhalt der Datei angezeigt."

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: "Das geht z.B. für .doc, .jpg, .pdf und noch für weitere Dateiformate."

, "Interested? Then let us know!"
: "Interessiert? Dann melden Sie sich bei uns!"

, "We would be happy to make you a non-binding offer."
: "Wir machen Ihnen gerne ein unverbindliches Angebot."

, "No preview available yet - Please try again in a few minutes."
: "Leider noch keine Vorschau verfügbar - Bitte versuchen Sie es in einigen Minuten erneut."

, "Notifications"
: "Benachrichtigungen"

, "This folder has own notification settings"
: "Dieser Ordner hat eigene Benachrichtigungs Einstellungen"

, "Notification"
: "Benachrichtigung"

, "Notification active"
: "Benachrichtigung aktiv"

, "Summary"
: "Zusammenfassung"

, "Once a Day, Every {0} Days"
: [
  "Einmal am Tag"
 ,"Alle {0} Tage"

]
, "No"
: "Nein"

, "Don't summarize"
: "Nicht zusammenfassen"

, "Once a day"
: "Einmal täglich"

, "Every 3 days"
: "Alle 3 Tage"

, "Once a week"
: "Einmal die Woche"

, "Once a month"
: "Einmal pro Monat"

, "Once a year"
: "Einmal pro Jahr"

, "Search for users ..."
: "Suche nach Benutzern ..."

, "No permission"
: "Keine Berechtigung"

, "all"
: "alle"

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "Grants"
: "Berechtigungen"

, "This folder has its own grants"
: "Diese Ordner hat eigene Berechtigungen"

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: "Rechte eines Ordners gelten auch rekursiv für alle Unterordner, es sei denn, sie verfügen über eigene Rechte."

, "This folder is part of the data safe"
: "Dieser Ordner ist Teil des Datentresors"

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: "Wenn der Datenschutz aktiviert ist, kann auf diesen Ordner und seinen Inhalt nur zugegriffen werden, wenn der Datenschutz geöffnet ist."

, "Usage"
: "Verbrauch"

, "This folder has own quota"
: "Dieser Ordner hat ein eigenes Kontingent"

, "Quota"
: "Kontingent"

, "No quota set (examples: 10 GB, 900 MB)"
: "Kein Kontingent gesetzt (Bsp.: 10 GB, 900 MB)"

, "Current Usage"
: "Aktuelle Nutzung"

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: "Das Kontingent gilt rekursiv für Dateien und Unterordner. Achtung: Das effektive Kontingent kann abweichen wenn ein übergeordneter Ordner eine geringeres Kontingent gesetzt hat."

, "File Type"
: "Dateityp"

, "Usage by File Type"
: "Verbrauch nach Dateityp"

, "User"
: "Benutzer"

, "Usage by User"
: "Verbrauch nach Benutzer"

, "unknown"
: "unbekannt"

, "Reload"
: "Aktualisieren"

, "Create Folder"
: "Ordner anlegen"

, "New Folder"
: "Neuer Ordner"

, "Please enter the name of the new folder:"
: "Bitte geben Sie den Namen für den neuen Ordner ein:"

, "No {0} added"
: "Kein {0} hinzugefügt"

, "You have to supply a {0} name!"
: "Sie müssen einen {0}-namen angeben!"

, "Edit Properties"
: "Eigenschaften bearbeiten"

, "Rename"
: "Umbenennen"

, "Rename {0}"
: "{0} umbenennen"

, "Please enter the new name of the {0}:"
: "Bitte den neuen Namen von {0} eingeben:"

, "Not renamed {0}"
: "Unbenannter {0}"

, "System Link"
: "System Link"

, "Use this link to share the entry with other system users"
: "Verwende diesen Link um den Eintrag mit einem anderen Systembenutzer zu teilen"

, "Delete"
: "Löschen"

, "Do you really want to delete the following files?"
: "Möchten Sie folgende Datei(en) löschen?"

, "Move"
: "Verschieben"

, "Move Items"
: "Einträge verschieben"

, "Preview"
: "Vorschau"

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: "Download Links können mit einem Passwort geschützt werden. Wenn kein Passwort angegeben ist, kann jeder der den Link kennt auf die selektierten Dateien zugreifen."

, "Folder has been published successfully"
: "Ordner wurde erfolgreich veröffentlicht"

, "File has been published successfully"
: "Datei wurde erfolgreich veröffentlicht"

, "Public Download URL"
: "Öffentliche Download URL"

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: "Liefern Sie anonyme Downloads von einer anderen URL. Stellen Sie sicher, dass die Umschreiberegeln entsprechend angepasst sind."

, "you can't remove your own admin grant"
: "Sie können Ihr eigenes Administrator-Recht nicht entfernen"

, "My folders"
: "Meine Ordner"

, "Shared folders"
: "Gemeinsame Ordner"

, "Other users folders"
: "Ordner anderer Benutzer"

, "Received"
: "Erhalten"

, "To"
: "An"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "From (E-Mail)"
: "Von (E-Mail)"

, "From (Name)"
: "Von (Name)"

, "Body"
: "Inhalt"

, "Attachments"
: "Anhänge"

, "Destination is a Subfolder"
: "Ziel ist ein Unterordner"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "Das Ziel ist ein Unterordner. Es ist nicht erlaubt einen Ordner in einen seiner Unterordner zu kopieren oder zu verschieben."

, "Destination has the same Path"
: "Ziel hat den gleichen Pfad"

, "The destination has the same path as the source. No action has been performed."
: "Das Ziel hat den selben Pfad wie die Quelle. Die Aktion wurde nicht ausgeführt."

, "manage shared folders"
: "Gemeinsame Ordner verwalten"

, "Create new shared folders"
: "Neue gemeinsame Ordner anlegen und verwalten"

, "Manage anonymous download links"
: "Anonyme Download Links verwalten"

, "Allow viewing, adding and deleting download links"
: "Anzeigen, Hinzufügen und Löschen von Download Links erlauben"






















, "Folder"
: "Ordner"

, "File"
: "Datei"

, "Download Link"
: "Download Link"

, "Once a Day"
: "Einmal am Tag"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Filemanager/js/Filemanager-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-04-06 12:24+0200\nLast-Translator: Paul Hartog <p.hartog@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.3\n"

, "Password for download required"
: "Zum Herunterladen Passwort eingeben"

, "Submit"
: "Abschicken"

, "File not found!"
: "Datei nicht gefunden!"

, "Name"
: "Name"

, "Size"
: "Größe"

, "Last Modified"
: "Letzter Änderungszeitpunkt"

, "Description"
: "Beschreibung"

, "Folder, Folders"
: [
  "Ordner"
 ,"Ordner"

]
, "File, Files"
: [
  "Datei"
 ,"Dateien"

]
, "Default behavior when double-clicking on a Row"
: "Standardverhalten beim Doppelklicken auf eine Zeile"

, "Defines which action should be executed by default when double-clicked."
: "Legt fest, welche Aktion bei einem Doppelklick standardmäßig ausgeführt werden soll."

, "Invalid Filename"
: "Ungültiger Dateiname"

, "Content type"
: "Inhaltstyp"

, "path"
: "Pfad"

, "URL"
: "URL"

, "Password"
: "Passwort"

, "Valid until"
: "Gültig bis"

, "Send as e-mail"
: "Sende als E-Mail"

, "Download"
: "Herunterladen"

, "Create Public Link"
: "Öffentlichen Link erstellen"

, "Remove record"
: "Eintrag entfernen"

, "Creating new Download Link..."
: "Erstelle neuen Download Link..."

, "Deleting Download Links..."
: "Lösche Download Links..."

, "Deleting Download Link..."
: "Lösche Download Link..."

, "Created By"
: "Erstellt von"

, "Creation Time"
: "Erstellt am"

, "Expiration Time"
: "Fristablauf"

, "Access Count"
: "Anzahl der Zugriffe"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Revision"
: "Version"

, "This folder has own revision settings"
: "Dieser Ordner hat eigene Revisions Einstellungen"

, "Revision active"
: "Revision aktiv"

, "Limit revision amount to"
: "Revisionen limitieren auf"

, "Hold-back in months"
: "Vorhalten in Monaten"

, "Upload Failed"
: "Hochladen fehlgeschlagen"

, "It is not permitted to store files in this folder!"
: "In diesem Ordner dürfen keine Dateien abgelegt werden!"

, "Select a file"
: "Wähle eine Datei"

, "Select files"
: "Wähle Dateien aus"

, "Select a folder"
: "Wähle einen Ordner aus"

, "Select folders"
: "Ordner Auswählen"

, "Select an item"
: "Wähle einen Artikel aus"

, "Select items"
: "Artikel Auswählen"

, "Checking ..."
: "Prüfe…"

, "Overwrite Existing File?"
: "Bestehende Datei Überschreiben?"

, "Do you really want to overwrite the selected file?"
: "Wollen Sie wirklich die ausgewählten Dateien überschreiben?"

, "Tags"
: "Tags"

, "Revision Size"
: "Revisions Größe"

, "Total size of all available revisions"
: "Gesamtgröße der verfügbaren Revisionen"

, "Indexed"
: "Indiziert"

, "File contents is part of the search index"
: "Dateiinhalte sind im Suchindex"

, "Upload"
: "Hochladen"

, "Open Data Safe"
: "Datentresor öffnen"

, "Folder Up"
: "Aufwärts"

, "Close Data Safe"
: "Datentresor schließen"

, "Filemanager"
: "Dateimanager"

, "Save locally"
: "Lokal speichern"

, "Close"
: "Schließen"

, "Loading preview ..."
: "Lade Vorschau …"

, "Edit folder"
: "Ordner bearbeiten"

, "edit file"
: "Datei bearbeiten"

, "Public Links"
: "Öffentliche Links"

, "Type"
: "Typ"

, "Not yet indexed"
: "Noch nicht indiziert"

, "Modified By"
: "Zuletzt geändert von"

, "Enter description"
: "Beschreibung eingeben"

, "Service Unavailable"
: "Dienst nicht verfügbar"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Der Dateimanager ist nicht korrekt konfiguriert. Bitte kontaktieren sie ihren Administrator oder ziehen sie die {0}Tine 2.0 Dokumentation{1} zu Rate."

, "File(s) already exists"
: "Datei(en) schon vorhanden"

, "Do you want to replace the following file(s)?"
: "Möchten Sie die folgenden Datei(en) ersetzen?"

, "An error occurred creating this folder"
: "Beim Erstellen dieses Ordners ist ein Fehler aufgetreten"

, "Item with this name already exists!"
: "Item(s) mit diesem Namen schon vorhanden!"

, "Whole Filemanager"
: "Gesamter Dateimanager"

, "This Folder"
: "Dieser Ordner"

, "Search"
: "Suche"

, "The grant to download files"
: "Das Recht, Dateien zu herunterzuladen"

, "Publish"
: "Veröffentlichen"

, "The grant to create anonymous download links for files"
: "Das Recht, anonyme Download Links für Dateien zu erstellen"

, "Copying data .. {0}"
: "Kopiere Daten .. {0}"

, "Moving data .. {0}"
: "Verschiebe Daten .. {0}"

, "Please wait"
: "Bitte warten"

, "Error while uploading \"{fileName}\". Please try again later."
: "Fehler beim Hochladen von „{fileName}“ . Bitte versuchen Sie es später noch einmal."

, "Quick Search"
: "Schnellsuche"

, "Content Type"
: "Inhaltstyp"

, "File Contents"
: "Dateiinhalt"

, "Download Link, Download Links"
: [
  "Download Link"
 ,"Download Links"

]
, "Node Download Links"
: "Knoten Download Links"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: "Schade, gerne hätte Tine 2.0 Ihnen jetzt den Inhalt der Datei angezeigt."

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: "Das geht z.B. für .doc, .jpg, .pdf und noch für weitere Dateiformate."

, "Interested? Then let us know!"
: "Interessiert? Dann melden Sie sich bei uns!"

, "We would be happy to make you a non-binding offer."
: "Wir machen Ihnen gerne ein unverbindliches Angebot."

, "No preview available yet - Please try again in a few minutes."
: "Leider noch keine Vorschau verfügbar - Bitte versuchen Sie es in einigen Minuten erneut."

, "Notifications"
: "Benachrichtigungen"

, "This folder has own notification settings"
: "Dieser Ordner hat eigene Benachrichtigungs Einstellungen"

, "Notification"
: "Benachrichtigung"

, "Notification active"
: "Benachrichtigung aktiv"

, "Summary"
: "Zusammenfassung"

, "Once a Day, Every {0} Days"
: [
  "Einmal am Tag"
 ,"Alle {0} Tage"

]
, "No"
: "Nein"

, "Don't summarize"
: "Nicht zusammenfassen"

, "Once a day"
: "Einmal täglich"

, "Every 3 days"
: "Alle 3 Tage"

, "Once a week"
: "Einmal die Woche"

, "Once a month"
: "Einmal pro Monat"

, "Once a year"
: "Einmal pro Jahr"

, "Search for users ..."
: "Suche nach Benutzern ..."

, "No permission"
: "Keine Berechtigung"

, "all"
: "alle"

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "Grants"
: "Berechtigungen"

, "This folder has its own grants"
: "Diese Ordner hat eigene Berechtigungen"

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: "Rechte eines Ordners gelten auch rekursiv für alle Unterordner, es sei denn, sie verfügen über eigene Rechte."

, "This folder is part of the data safe"
: "Dieser Ordner ist Teil des Datentresors"

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: "Wenn der Datenschutz aktiviert ist, kann auf diesen Ordner und seinen Inhalt nur zugegriffen werden, wenn der Datenschutz geöffnet ist."

, "Usage"
: "Verbrauch"

, "This folder has own quota"
: "Dieser Ordner hat ein eigenes Kontingent"

, "Quota"
: "Kontingent"

, "No quota set (examples: 10 GB, 900 MB)"
: "Kein Kontingent gesetzt (Bsp.: 10 GB, 900 MB)"

, "Current Usage"
: "Aktuelle Nutzung"

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: "Das Kontingent gilt rekursiv für Dateien und Unterordner. Achtung: Das effektive Kontingent kann abweichen wenn ein übergeordneter Ordner eine geringeres Kontingent gesetzt hat."

, "File Type"
: "Dateityp"

, "Usage by File Type"
: "Verbrauch nach Dateityp"

, "User"
: "Benutzer"

, "Usage by User"
: "Verbrauch nach Benutzer"

, "unknown"
: "unbekannt"

, "Reload"
: "Aktualisieren"

, "Create Folder"
: "Ordner anlegen"

, "New Folder"
: "Neuer Ordner"

, "Please enter the name of the new folder:"
: "Bitte geben Sie den Namen für den neuen Ordner ein:"

, "No {0} added"
: "Kein {0} hinzugefügt"

, "You have to supply a {0} name!"
: "Sie müssen einen {0}-namen angeben!"

, "Edit Properties"
: "Eigenschaften bearbeiten"

, "Rename"
: "Umbenennen"

, "Rename {0}"
: "{0} umbenennen"

, "Please enter the new name of the {0}:"
: "Bitte den neuen Namen von {0} eingeben:"

, "Not renamed {0}"
: "Unbenannter {0}"

, "System Link"
: "System Link"

, "Use this link to share the entry with other system users"
: "Verwende diesen Link um den Eintrag mit einem anderen Systembenutzer zu teilen"

, "Delete"
: "Löschen"

, "Do you really want to delete the following files?"
: "Möchten Sie folgende Datei(en) löschen?"

, "Move"
: "Verschieben"

, "Move Items"
: "Einträge verschieben"

, "Preview"
: "Vorschau"

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: "Download Links können mit einem Passwort geschützt werden. Wenn kein Passwort angegeben ist, kann jeder der den Link kennt auf die selektierten Dateien zugreifen."

, "Folder has been published successfully"
: "Ordner wurde erfolgreich veröffentlicht"

, "File has been published successfully"
: "Datei wurde erfolgreich veröffentlicht"

, "Public Download URL"
: "Öffentliche Download URL"

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: "Liefern Sie anonyme Downloads von einer anderen URL. Stellen Sie sicher, dass die Umschreiberegeln entsprechend angepasst sind."

, "you can't remove your own admin grant"
: "Sie können Ihr eigenes Administrator-Recht nicht entfernen"

, "My folders"
: "Meine Ordner"

, "Shared folders"
: "Gemeinsame Ordner"

, "Other users folders"
: "Ordner anderer Benutzer"

, "Received"
: "Erhalten"

, "To"
: "An"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "From (E-Mail)"
: "Von (E-Mail)"

, "From (Name)"
: "Von (Name)"

, "Body"
: "Inhalt"

, "Attachments"
: "Anhänge"

, "Destination is a Subfolder"
: "Ziel ist ein Unterordner"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "Das Ziel ist ein Unterordner. Es ist nicht erlaubt einen Ordner in einen seiner Unterordner zu kopieren oder zu verschieben."

, "Destination has the same Path"
: "Ziel hat den gleichen Pfad"

, "The destination has the same path as the source. No action has been performed."
: "Das Ziel hat den selben Pfad wie die Quelle. Die Aktion wurde nicht ausgeführt."

, "manage shared folders"
: "Gemeinsame Ordner verwalten"

, "Create new shared folders"
: "Neue gemeinsame Ordner anlegen und verwalten"

, "Manage anonymous download links"
: "Anonyme Download Links verwalten"

, "Allow viewing, adding and deleting download links"
: "Anzeigen, Hinzufügen und Löschen von Download Links erlauben"

, "This file has no contents. The Upload has failed or has not yet finished."
: "Diese Datei hat keinen Inhalt. Der Upload ist entweder fehlgeschlagen oder noch nicht fertig."






















, "Folder"
: "Ordner"

, "File"
: "Datei"

, "Download Link"
: "Download Link"

, "Once a Day"
: "Einmal am Tag"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
